## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL,
    message = FALSE
)

## ----eval = FALSE-------------------------------------------------------------
# if(!requireNamespace("BiocManager", quietly = TRUE))
#         install.packages("BiocManager")
# BiocManager::install("ProteinGymR")

## ----message = FALSE----------------------------------------------------------
library(ProteinGymR)
library(tidyr)
library(dplyr)
library(stringr)
library(ggplot2)
library(ComplexHeatmap)
library(AnnotationHub)

## ----import dms---------------------------------------------------------------
dms_data <- dms_substitutions()

## ----view studies-------------------------------------------------------------
head(names(dms_data))

## ----view assay---------------------------------------------------------------
head(dms_data[[1]])

## ----queryEH------------------------------------------------------------------
eh <- ExperimentHub::ExperimentHub()
AnnotationHub::query(eh, "ProteinGymR")

dms_metadata <- eh[["EH9607"]]
names(dms_metadata)

## ----ACE2 heatmap-------------------------------------------------------------
plot_dms_heatmap(assay_name = "ACE2_HUMAN_Chan_2020", 
    dms_data = dms_data, start_pos = 10, end_pos = 100)

## ----available_models---------------------------------------------------------
available_models()

## ----warning=FALSE, fig.wide = TRUE-------------------------------------------
benchmark_models(metric = "AUC", 
    models = c("GEMME", "CARP_600K", "ESM_1b", "EVmutation", "ProtGPT2"))

## ----sesh info----------------------------------------------------------------
sessionInfo()

